@@ -1,4 +1,7 @@
 from functools import partial, wraps
+import logging
+from pprint import pformat
+from signal import signal, SIGUSR1
 from . expr import Parser
 from . mqtt import topic
 
@@ -17,6 +20,7 @@ class StateAwareMixin:
     
     conditions = {}
     parser = Parser()
+    update_log_level = logging.INFO
     
     def __init__(self):
         'Register topics and the state callcack.'
@@ -31,6 +35,9 @@ class StateAwareMixin:
         register = topic(status_topic, payload_converter=self.decode_json)
         register(self.update_status)
 
+        # Dump curent state on USR1 signal
+        signal(SIGUSR1, self.dump_state)
+
 
     @staticmethod
     def update_status(self, _userdata, msg):
@@ -50,7 +57,7 @@ class StateAwareMixin:
         # Update only if the value has changed
         if self.current_state.get(topic) != payload:
             self.current_state[topic] = payload
-            self.log.info('Updated: %s = %s', topic, payload)
+            self.log.log(self.update_log_level, 'Updated: %s = %s', topic, payload)
             return topic
     
     
@@ -74,6 +81,11 @@ class StateAwareMixin:
         return super().publish(topic, payload, **kw)
 
 
+    def dump_state(self, _signal, _frame):
+        'Print status information'
+        print('Current state: ' + pformat(self.current_state))
+
+
 def conditional(expression):
     ''' Decorated a status handler method which is invoked
         with the value of the expression
